aboutsummaryrefslogtreecommitdiff
path: root/sys/powerpc/aim
diff options
context:
space:
mode:
authorKonstantin Belousov <kib@FreeBSD.org>2022-07-18 16:39:17 +0000
committerKonstantin Belousov <kib@FreeBSD.org>2022-08-02 18:11:09 +0000
commitc6d31b8306eb708441c61c33bcf886ecad268a16 (patch)
tree3e61512a31b669d0e150722644eed72dd95516f5 /sys/powerpc/aim
parent4a5ec55af6d0bfa659f67483e346d55f90ba0856 (diff)
Diffstat (limited to 'sys/powerpc/aim')
-rw-r--r--sys/powerpc/aim/trap_subr32.S6
-rw-r--r--sys/powerpc/aim/trap_subr64.S6
2 files changed, 4 insertions, 8 deletions
diff --git a/sys/powerpc/aim/trap_subr32.S b/sys/powerpc/aim/trap_subr32.S
index 9664dcc92d2d..1193b52dc3b3 100644
--- a/sys/powerpc/aim/trap_subr32.S
+++ b/sys/powerpc/aim/trap_subr32.S
@@ -801,11 +801,9 @@ CNAME(trapexit):
bf 17,1f /* branch if PSL_PR is false */
GET_CPUINFO(%r3) /* get per-CPU pointer */
- lwz %r4, TD_FLAGS(%r2) /* get thread flags value
+ lwz %r4, TD_AST(%r2) /* get thread ast value
* (r2 is curthread) */
- lis %r5, (TDF_ASTPENDING|TDF_NEEDRESCHED)@h
- ori %r5,%r5, (TDF_ASTPENDING|TDF_NEEDRESCHED)@l
- and. %r4,%r4,%r5
+ cmpwi %r4, 0
beq 1f
mfmsr %r3 /* re-enable interrupts */
ori %r3,%r3,PSL_EE@l
diff --git a/sys/powerpc/aim/trap_subr64.S b/sys/powerpc/aim/trap_subr64.S
index 8ab2c57be7cb..7d86316515f6 100644
--- a/sys/powerpc/aim/trap_subr64.S
+++ b/sys/powerpc/aim/trap_subr64.S
@@ -871,10 +871,8 @@ CNAME(trapexit):
bf 17,1f /* branch if PSL_PR is false */
GET_CPUINFO(%r3) /* get per-CPU pointer */
- lwz %r4, TD_FLAGS(%r13) /* get thread flags value */
- lis %r5, (TDF_ASTPENDING|TDF_NEEDRESCHED)@h
- ori %r5,%r5, (TDF_ASTPENDING|TDF_NEEDRESCHED)@l
- and. %r4,%r4,%r5
+ lwz %r4,TD_AST(%r13) /* get thread ast value */
+ cmpwi %r4,0
beq 1f
mfmsr %r3 /* re-enable interrupts */
ori %r3,%r3,PSL_EE@l